@@ -29,6 +29,7 @@ from .._shared_files import logger
 from .._shared_files.context_managers import active_lattice_manager
 from .._shared_files.defaults import (
     _DEFAULT_CONSTRAINT_VALUES,
+    arg_prefix,
     attr_prefix,
     electron_dict_prefix,
     electron_list_prefix,
@@ -42,7 +43,7 @@ from .lattice import Lattice
 
 consumable_constraints = ["budget", "time_limit"]
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from ..executor import BaseExecutor
     from .transport import _TransportGraph
 
